<img src="https://github.com/user-attachments/assets/414c5db6-828c-4fd2-9bb0-1010ed59eecb" width=50%> [![Documentation Status](https://readthedocs.org/projects/rahrah/badge/?version=latest)](https://rahrah.readthedocs.io/en/latest/?badge=latest) [![DOI](https://zenodo.org/badge/894175735.svg)](https://doi.org/10.5281/zenodo.14300869)

University-inspired matplotlib color palettes and colormaps. Colors are taken directly from University branding guidelines, so there is no specific effort toward perceptual uniformity or accessibility for color blindness beyond the aesthetic choices I made in putting the palettes/colormaps together. Please check your plots/figures with [COBLIS](https://www.color-blindness.com/coblis-color-blindness-simulator/) or similar.

## Installation
To install:
```bash
cd ~

git clone git@github.com:avapolzin/rahrah.git

cd rahrah

sudo python3 setupy.py install

````
or 
```bash
pip install rahrah
```

If you use this package or the scripts in this repository in a publication, please add a footnote linking to https://github.com/avapolzin/rahrah and/or consider adding this software to your acknowledgments. If you would like to cite `rahrah`, please use the Zenodo DOI linked here. 

I'd love to feature plots/figures that make use of these palettes in the wild, so should these palettes be of use, please send me a copy of that figure and/or a link to your paper or presentation and I will share it here.

(Interested in palettes and colormaps based on album covers? Check out [`albumpl`](https://github.com/avapolzin/albumpl).)

## Palettes/Colormaps
To request the addition of a new school's palette/colormap, please open an issue, linking to the university's branding guidelines.

Included palettes (to now):


1. __Albion__ (Albion College)
![Albion_summary](https://github.com/user-attachments/assets/b493bcb1-f8c5-4778-b809-bdfe65b01c65)

2. __Amherst__ (Amherst College)
![Amherst_summary](https://github.com/user-attachments/assets/be023d81-5c3a-4318-a110-094f69410bb7)

3. __ASU__ (Arizona State University)
![ASU_summary](https://github.com/user-attachments/assets/b226b06e-2815-4e28-9e88-36ffc8b98099)

4. __Bowdoin__ (Bowdoin College)
![Bowdoin_summary](https://github.com/user-attachments/assets/ce003524-d78f-4317-965e-60b20874888a)

5. __Brown__ (Brown University)
![Brown_summary](https://github.com/user-attachments/assets/1ae000dd-3efe-4966-bf2b-68c7b229c100)

6. __BrownBright__ (Brown University)
![BrownBright_summary](https://github.com/user-attachments/assets/87f50a5d-ff85-4375-bf18-8c1307552da7)

7. __Caltech__ (California Institute of Technology)
![Caltech_summary](https://github.com/user-attachments/assets/671f0a87-fd52-41bd-9201-45c319c278a5)

8. __CaltechBright__ (California Institute of Technology)
![CaltechBright_summary](https://github.com/user-attachments/assets/3d6dea8e-1e07-4b13-8a0b-afa4e1e2d458)

9. __CarnegieMellon__ (Carnegie Mellon University)
![CarnegieMellon_summary](https://github.com/user-attachments/assets/e24a0d04-11b2-4b1f-8805-040c66135ebd)

10. __CarnegieMellonBright__ (Carnegie Mellon University)
![CMUBright_summary](https://github.com/user-attachments/assets/00a49320-c3cd-41b3-915c-e420879cda15)

11. __CUNY__ (City University of New York)
![CUNY_summary](https://github.com/user-attachments/assets/4f0eeb89-227d-4784-868d-709869aa20bc)

12. __Colgate__ (Colgate University)
![Colgate_summary](https://github.com/user-attachments/assets/8620edae-c5f7-4aea-83f0-428116ed95e8)

13. __Columbia__ (Columbia University)
![Columbia_summary](https://github.com/user-attachments/assets/fead0f1e-4962-4f2f-81d4-8e6c7d99195f)

14. __ColumbiaBright__ (Columbia University)
![ColumbiaBright_summary](https://github.com/user-attachments/assets/e7f81f93-5b4b-4ffc-903b-047c98085884)

15. __Cornell__ (Cornell University)
![Cornell_summary](https://github.com/user-attachments/assets/f5552a73-79b6-49bd-a9f0-0b0b9a0e1b69)

16. __Dartmouth__ (Dartmouth College)
![Dartmouth_summary](https://github.com/user-attachments/assets/a142ffef-6d51-4158-8b5e-fef778715a0e)

17. __DartmouthMono__ (Dartmouth College)
![DartmouthMono_summary](https://github.com/user-attachments/assets/7a4bb210-98f2-426f-bc0e-afc43be58a1c)

18. __Duke__ (Duke University)
![Duke_summary](https://github.com/user-attachments/assets/eb1e8210-dd0c-47bc-ad06-18fb6602307c)

19. __GeorgiaTech__ (Georgia Institute of Technology)
![GeorgiaTech_summary](https://github.com/user-attachments/assets/e55095eb-438a-48d6-b82a-2dddb88b0016)

20. __GSU__ (Georgia State University)
![GeorgiaState_summary](https://github.com/user-attachments/assets/e7aa415c-d317-48ed-b394-23eb685a4820)

21. __Harvard__ (Harvard University)
![Harvard_summary](https://github.com/user-attachments/assets/59cbd068-fca3-4174-8408-efb1aa3bdae5)

22. __HarveyMudd__ (Harvey Mudd College)
![HarveyMudd_summary](https://github.com/user-attachments/assets/8a8d2e4b-c6c1-4e16-ae9b-d67167253a1b)

23. __Haverford__ (Haverford College)
![Haverford_summary](https://github.com/user-attachments/assets/032ad2d5-6c4c-4dd3-a5d1-8214cad370cf)

24. __Indiana__ (Indiana University)
![Indiana_summary](https://github.com/user-attachments/assets/aab0f896-43a6-499e-a12a-fea5c31ebe69)

25. __JohnsHopkins__ (Johns Hopkins University)
![JohnsHopkins_summary](https://github.com/user-attachments/assets/62c3807c-76eb-4c52-a2b4-302176af479a)

26. __JohnsHopkinsMono__ (Johns Hopkins University)
![JohnsHopkinsMono_summary](https://github.com/user-attachments/assets/0a1b5e4b-783f-4b1a-8268-575d3dadba31)

27. __MIT__ (Massachusetts Institute of Technology)
![MIT_summary](https://github.com/user-attachments/assets/6a3f1e30-e3ac-4579-bdf7-148c25f2a161)

28. __MITBright__ (Massachusetts Institute of Technology)
![MITBright_summary](https://github.com/user-attachments/assets/82854069-eb1f-4015-bca6-3f924385c930)

29. __McGill__ (McGill University)
![McGill_summary](https://github.com/user-attachments/assets/3e532202-1705-4e47-b7e0-adc69b701d69)

30. __MichiganState__ (Michigan State University)
![MichiganState_summary](https://github.com/user-attachments/assets/784f61a6-a490-464f-9294-2735f32af0ae)

31. __Middlebury__ (Middlebury College)
![Middlebury_summary](https://github.com/user-attachments/assets/ba6dd9bb-2e97-4370-8c96-c7a68e59b927)

32. __NMSU__ (New Mexico State University)
![NMSU_summary](https://github.com/user-attachments/assets/8641ea4c-a002-411a-9b5b-c4fd159e32b3)

33. __NYU__ (New York University)
![NYU_summary](https://github.com/user-attachments/assets/ce742251-7171-4a19-a287-9b826a6cba6f)

34. __NCState__ (North Carolina State University)
![NCState_summary](https://github.com/user-attachments/assets/82bafe75-c266-46af-8a32-9ef70e87c363)

35. __NIU__ (Northern Illinois University)
![NIU_summary](https://github.com/user-attachments/assets/29c24250-eb37-40de-9091-8487f9f0a712)

36. __Northwestern__ (Northwestern University)
![Northwestern_summary](https://github.com/user-attachments/assets/bd55ef2f-40e2-4033-9730-544d99b22706)

37. __NotreDame__ (Notre Dame University)
![NotreDame_summary](https://github.com/user-attachments/assets/dd603596-e181-4e01-8e5f-3d21c9a0785e)

38. __Oberlin__ (Oberlin College and Conservatory)
![Oberlin_summary](https://github.com/user-attachments/assets/03d98801-a759-4e12-89d7-d17abc2865be)

39. __OhioState__ (The Ohio State University)
![OhioState_summary](https://github.com/user-attachments/assets/918e280b-0dd0-4875-b8f8-3ac7dafa483e)

40. __OregonState__ (Oregon State University)
![OregonState_summary](https://github.com/user-attachments/assets/c43ecc3e-cd6d-4c36-9675-47bd969e9302)

41. __PennState__ (The Pennsylvania State University)
![PennState_summary](https://github.com/user-attachments/assets/721609dc-3c39-4aea-b75e-1f2ff9f21621)

42. __Princeton__ (Princeton University)
![Princeton_summary](https://github.com/user-attachments/assets/fa0d2271-d804-4e69-9cfe-3063de16cbb0)

43. __Purdue__ (Purdue University)
![Purdue_summary](https://github.com/user-attachments/assets/dd319508-0b07-485f-99af-6a386d20a0ce)

44. __QUB__ (Queen's University Belfast)
![QUB_summary](https://github.com/user-attachments/assets/cb2b1f0a-f064-4cd0-b628-9989ad4e0039)

45. __QUBBright__ (Queen's University Belfast)
![QUBBright_summary](https://github.com/user-attachments/assets/daa0d4a3-ec89-4088-9e6a-96501f36da40)

46. __Reed__ (Reed College)
![Reed_summary](https://github.com/user-attachments/assets/92111ab6-170b-41d3-8794-09141838a365)

47. __Rutgers__ (Rutgers, The State University of New Jersey)
![Rutgers_summary](https://github.com/user-attachments/assets/852d1a16-c3ee-445a-a757-6bfef480e7c5)

48. __Stanford__ (Stanford University)
![Stanford_summary](https://github.com/user-attachments/assets/8deec9c0-fa13-4e43-9bb5-cf121536ba69)

49. __StonyBrook__ (The State University of New York at Stony Brook)
![StonyBrook_summary](https://github.com/user-attachments/assets/3a119ceb-9e7f-44ef-84a5-1763f7186b82)

50. __Syracuse__ (Syracuse University)
![Syracuse_summary](https://github.com/user-attachments/assets/b8f02665-89a2-4b60-981f-58ebf5feff4a)

51. __Arizona__ (University of Arizona)
![Arizona_summary](https://github.com/user-attachments/assets/834bcdff-b697-475a-ac94-7b9504f2a38c)

52. __UBC__ (University of British Columbia)
![UBC_summary](https://github.com/user-attachments/assets/ed5eca1e-9cb6-4fe8-b059-7d81ac104ade)

53. __Berkeley__ (University of California, Berkeley)
![Berkeley_summary](https://github.com/user-attachments/assets/b61e0278-82db-4998-a4c0-d5c53d0c5cc8)

54. __UCLA__ (University of California, Los Angeles)
![UCLA_summary](https://github.com/user-attachments/assets/8faf841e-0f27-47cb-b340-82bdf97f61f8)

55. __Cambridge__ (University of Cambridge)
![Cambridge_summary](https://github.com/user-attachments/assets/bc9e73b1-c4cf-4a9a-9e1d-ecaa64b0e24b)

56. __Chicago__ (The University of Chicago)
![chicago_summary](https://github.com/user-attachments/assets/b432a9b3-47a4-4e33-831b-6ae4c4c5ac18)

57. __ChicagoBright__ (The University of Chicago)
![ChicagoBright_summary](https://github.com/user-attachments/assets/f928272c-ecfd-4223-bff1-0c0a075f174e)

58. __Colorado__ (University of Colorado Boulder)
![Colorado_summary](https://github.com/user-attachments/assets/ae2bab4b-24dc-49ce-b6b4-d7ae5dc70815)

59. __UConn__ (University of Connecticut)
![UConn_summary](https://github.com/user-attachments/assets/df293af7-a7a2-45ed-99fe-de4fe618c5aa)

60. __Idaho__ (University of Idaho)
![Idaho_summary](https://github.com/user-attachments/assets/044dbaa8-96dc-423e-9e68-001023ee4cfa)

61. __Illinois__ (University of Illinois)
![Illinois_summary](https://github.com/user-attachments/assets/8dcdb960-58c4-46f0-95b8-eca23dc49d1f)

62. __Iowa__ (University of Iowa)
![Iowa_summary](https://github.com/user-attachments/assets/40b5cea6-9ae8-448b-9cd3-1bf0fd85742f)

63. __Kansas__ (University of Kansas)
![Kansas_summary](https://github.com/user-attachments/assets/26457c88-4380-4b5c-9cb8-4a5379531944)

64. __Kentucky__ (University of Kentucky)
![Kentucky_summary](https://github.com/user-attachments/assets/e3d2c1ff-c814-4ada-8926-078b9cb6b5d1)

65. __Oxford__ (University of Oxford)
![Oxford_summary](https://github.com/user-attachments/assets/2829ee7e-05a2-4ed9-90a8-c39dada8fc96)

66. __Maryland__ (University of Maryland)
![Maryland_summary](https://github.com/user-attachments/assets/bfe5bbff-ef68-48fe-894a-d2ff1419f991)

67. __UMass__ (University of Massachusetts Amherst)
![UMass_summary](https://github.com/user-attachments/assets/af7f0fbb-1b18-4150-bde7-cb27aeb23921)

68. __UMassBright__ (University of Massachusetts Amherst)
![UMassBright_summary](https://github.com/user-attachments/assets/31e4f542-4413-4a96-a476-b1de32e48cce)

69. __Michigan__ (University of Michigan)
![Michigan_summary](https://github.com/user-attachments/assets/d27b0b10-7032-4ddc-b71a-1320e02c0967)

70. __Minnesota__ (University of Minnesota)
![Minnesota_summary](https://github.com/user-attachments/assets/3ceec51f-9190-4e0a-97a4-f31306f01995)

71. __Nebraska__ (University of Nebraska)
![Nebraska_summary](https://github.com/user-attachments/assets/bbb6b651-cb12-4df7-9c46-695ea971b39c)

72. __UNC__ (University of North Carolina Chapel Hill)
![UNC_summary](https://github.com/user-attachments/assets/827af657-1152-44d4-82ba-034f732448b0)

73. __UNCBright__ (University of North Carolina Chapel Hill)
![UNCBright_summary](https://github.com/user-attachments/assets/ec4eaafd-3329-4c64-80d4-d137e344be27)

74. __Oregon__ (University of Oregon)
![Oregon_summary](https://github.com/user-attachments/assets/e7f93c4e-b91b-4214-a14e-8a76b2f4dd7b)

75. __Penn__ (University of Pennsylvania)
![Penn_summary](https://github.com/user-attachments/assets/7e7d6c84-6e71-4142-8ccc-c3b40627555c)

76. __Pitt__ (University of Pittsburgh)
![Pitt_summary](https://github.com/user-attachments/assets/0f808d9c-10d6-485f-8257-cb02f14b19d1)

77. __USC__ (University of Southern California)
![USC_summary](https://github.com/user-attachments/assets/59e6bbcb-7dfd-4079-9d57-66c9eddcf463)

78. __Texas__ (University of Texas)
![Texas_summary](https://github.com/user-attachments/assets/ebdefefa-65d4-4f05-b7b5-5853db47788c)

79. __Toronto__ (University of Toronto)
![Toronto_summary](https://github.com/user-attachments/assets/b5de86fd-5959-4420-afc0-b1ec05265f1d)

80. __Utah__ (University of Utah)
![Utah_summary](https://github.com/user-attachments/assets/63f2b348-fe2c-4947-9c3e-d7c22030a177)

81. __UVA__ (University of Virginia)
![Virginia_summary](https://github.com/user-attachments/assets/475d8b45-edf3-458a-8c27-947b5d3f221b)

82. __Washington__ (University of Washington)
![Washington_summary](https://github.com/user-attachments/assets/fe7002be-ba97-4afc-9dc5-3a6e7408c624)

83. __Wisconsin__ (University of Wisconsin)
![Wisconsin_summary](https://github.com/user-attachments/assets/c0c5678f-b20d-4240-807e-4522158e3663)

84. __Vanderbilt__ (Vanderbilt University)
![Vanderbilt_summary](https://github.com/user-attachments/assets/0256c9e1-73d9-4c03-b493-dd77620f3102)

85. __Wellesley__ (Wellesley College)
![Wellesley_summary](https://github.com/user-attachments/assets/05c9f42c-cb89-4dad-ba40-e494fce3df3a)

86. __WVU__ (West Virginia University)
![WestVirginia_summary](https://github.com/user-attachments/assets/a096c6bb-dafd-456d-81f7-13c8b5bd4619)

87. __Yale__ (Yale University)
![yale_summary](https://github.com/user-attachments/assets/6a52ff2c-4465-453f-a9b5-943d94d47a3f)

There are also some alternative colormaps that are not the default associated with a specific palette, but are still callable.
  
<img src="https://github.com/user-attachments/assets/e7c2a57c-b297-4e8d-aec3-c9cdc55c364f" width="30%"><img src="https://github.com/user-attachments/assets/d76d8d34-b4dd-4c64-9d07-6a7d58d5611b" width="30%"><img src="https://github.com/user-attachments/assets/94ba5e48-cf95-4c33-92ea-e94a275f3cfb" width=30%><img src="https://github.com/user-attachments/assets/609dbe5d-d4b5-4bd8-8612-5aee6f04492e" width="30%"><img src="https://github.com/user-attachments/assets/b80d03d0-23f0-45f0-8836-b2a7f60b325f" width="30%"><img src="https://github.com/user-attachments/assets/0554f089-0473-4405-89cc-0b912f0776ad" width="30%"><img src="https://github.com/user-attachments/assets/b4513bc6-157e-4eb1-9f0f-940c025361d4" width=30%><img src="https://github.com/user-attachments/assets/e782fc9f-be81-4499-ba92-ed3716fa6a86" width=30%><img src="https://github.com/user-attachments/assets/f2e00ebb-c2f6-4543-a973-1046277587ce" width=30%><img src="https://github.com/user-attachments/assets/b06017bd-e405-451f-b3cd-604ae0ac493b" width=30%>



*** 
## How to use `rahrah`:

- **To list all palettes and their properties:**
```python
from rahrah.palette import list_palettes

list_palettes()
```
*You can also filter for number of colors in the color cycle or type of colormap (sequential/diverging) with the arguments `mincolors` and `maptype`.*

- **To list all colormaps:**
```python
from rahrah.cmap import list_maps

list_maps()
```

- **To set palette as default for both color cycle *and* colormap:**
```python
from rahrah.palette import set_default

set_default('Northwestern')
```

- **To set a palette as default for color cycle *or* colormap:**
```python
from rahrah.palette import set_default_ccycle, set_default_cmap

set_default_ccycle('ChicagoBright')
```
*or*
```python
set_default_cmap('Yale')
```

- **To access colormaps without setting them as default:**

```python
import matplotlib.pyplot as plt
import rahrah.cmap

plt.imshow(image, cmap = 'USC')
```
To reverse the colormap, simply append '_r' to the name (e.g., 'USC' becomes 'USC_r').

- **To access the colors in a color cycle/palette without setting a default:**
```python
from rahrah.palette import return_colors

return_colors('BrownBright')
```

The lightness of all colormaps is shown below (all sequential maps are shown dark-to-light for easier comparison):
![rahrahlightness 001](https://github.com/user-attachments/assets/ed734692-9ee7-4500-bf25-4e97af3af455)
